@@ -13,10 +13,10 @@
         "InitIsoGrid": 64,
         "ParMaxGrid": 5000,
         "InitParGrid": 112,
-        "ScriptEditorFontSize": 18
+        "ScriptEditorFontSize": 12
     },
     "StartOptions": {
-        "Model": "CloseIso_1"
+        "Model": "Gyroid"
     },
     "ThreadsConfig": {
         "AutoDetect": true,
