@@ -96,6 +96,87 @@ struct GlobalParam
     uint NbVertexTmp = 0;
 };
 
+
+enum PreviousAction
+{
+    NOACTION = 0,
+    TORSX,
+    TORSY,
+    TORSZ,
+    SCALX,
+    SCALY,
+    SCALZ,
+    THICK
+};
+struct IsoThichnessParam
+{
+    QString ThExpression = "";
+    QString FctOriginal = "";
+    QStringList FctWithTh;
+    bool ShowOriginalSurf = true;
+    bool ShowUpperSurf = true;
+    bool ShowBottomSurf = false;
+};
+struct IsoScaleParam
+{
+    float Sx=1.0;
+    float Sy=1.0;
+    float Sz=1.0;
+
+    QString ScalX="$x$";
+    QString ScalY="$y$";
+    QString ScalZ="$z$";
+};
+struct IsoVarParameters
+{
+    QString Vx = "$X$";
+    QString Vy = "$Y$";
+    QString Vz = "$Z$";
+    PreviousAction Previousaction = NOACTION;
+};
+struct IsoTorsionParam
+{
+    int Tetax = 0;
+    int Tetay = 0;
+    int Tetaz = 0;
+    QString TorsionX="$x$";
+    QString TorsionY="$y$";
+    QString TorsionZ="$z$";
+};
+struct ParThichnessParam
+{
+    QString ThExpression = "";
+    bool ShowOriginalSurf = true;
+    bool ShowUpperSurf = true;
+    bool ShowBoumdarySurfs = false;
+};
+struct ParScaleParam
+{
+    float Sx=1.0;
+    float Sy=1.0;
+    float Sz=1.0;
+
+    QString ScalX="$x$";
+    QString ScalY="$y$";
+    QString ScalZ="$z$";
+};
+struct ParVarParameters
+{
+    QString Vx = "$X$";
+    QString Vy = "$Y$";
+    QString Vz = "$Z$";
+    PreviousAction Previousaction = NOACTION;
+};
+struct ParTorsionParam
+{
+    int Tetax = 0;
+    int Tetay = 0;
+    int Tetaz = 0;
+    QString TorsionX="$x$";
+    QString TorsionY="$y$";
+    QString TorsionZ="$z$";
+};
+
 struct ImplicitStructure
 {
     std::string fxyz;
@@ -131,7 +212,7 @@ struct NoiseParemeters
 
 struct ErrorMessage
 {
-    int iErrorIndex;
+    int iErrorIndex=-2;
     std::string strError;
     std::string ErrorType;
 };
@@ -192,7 +273,9 @@ enum ScriptErrorType
     VECT_DIMENSION_ERROR,
     MEM_OVERFLOW,
     GRID_VALUE_0,
-    EMPTY_MANDATORY_FIELD
+    EMPTY_MANDATORY_FIELD,
+    COMPLEX_FCTS_UNSUPPORTED,
+    PARISO_OBJ_UNSUPPORTED
 };
 
 static const char *ScriptErrorMessage[] =
@@ -235,8 +318,10 @@ static const char *ScriptErrorMessage[] =
         "INVALID_GRID_VALUE",
         "Vect_DIMENSION_ERROR",                     // 34
         "Not enough memory available to complete this operation", // 35
-        "GRID_VALUE_0",                          // 36
-        "EMPTY_MANDATORY_FIELD"                     // 37
+        "GRID_VALUE_0",                             // 36
+        "EMPTY_MANDATORY_FIELD",                    // 37
+        "COMPLEX_FCTS_UNSUPPORTED",                 //38
+        "PARISO_OBJ_UNSUPPORTED"
 };
 
 struct ComponentInfos
