@@ -109,6 +109,7 @@ class Iso3D  : public ParisoObject
 {
     Q_OBJECT
 public :
+    IsoVarParameters Isoxyz;
     IsoWorkerThread *workerthreads;
     IsoMasterThread *masterthread;
     std::vector<float> NormOriginaltmpVector;
@@ -136,6 +137,13 @@ public :
     void stopcalculations(bool);
     void WorkerThreadCopy(IsoWorkerThread *);
     ErrorMessage IsoMorph();
+    ErrorMessage IsoTorsion();
+    void InitGeneratorStruct();
+    ErrorMessage AddThickness();
+    ErrorMessage ScaleIso();
+    void InitScaleStruct();
+    void InitTorsionStruct();
+    void InitVarParam();
     ErrorMessage parse_expression2();
     ErrorMessage ThreadParsersCopy();
     void ReinitVarTablesWhenMorphActiv(uint);
