@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2024 by Abderrahman Taha                                *
+ *   Copyright (C) 2025 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,10 +19,31 @@
  ***************************************************************************/
 #include "parisoobject.h"
 
+
+std::vector<uint> ParisoObject::IndexPolyTabVector;
+std::vector<float> ParisoObject::NormVertexTabVector;
+std::vector<uint> ParisoObject::IndexPolyTabMinVector;
+std::vector<uint> ParisoObject::IndexPolyTabMinVector2;
+
 MasterThread::MasterThread() {}
 MasterThread::~MasterThread() {}
+
+
+void MasterThread::clearTextureInfos()
+{
+    RGBT_STR = VRGBT_STR = GRADIENT_STR = NOISE_STR="";
+}
+
 WorkerThread::WorkerThread() {}
 WorkerThread::~WorkerThread() {}
+uint WorkerThread::count_comma(const std::string s)
+{
+    uint count = 0, size=0;
+    size=s.size();
+    for (uint i = 0; i < size; i++)
+        if (s[i] == ',') count++;
+    return count;
+}
 ParisoObject::ParisoObject() {}
 ParisoObject::~ParisoObject() {}
 uint ParisoObject::CNDtoUse(uint index, struct ComponentInfos *components)
