@@ -17,6 +17,9 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
  ***************************************************************************/
+#ifndef VIDEO_H
+#define VIDEO_H
+
 #include <qfiledialog.h>
 #include <qgroupbox.h>
 #include <qimage.h>
@@ -24,19 +27,20 @@
 #include <qmainwindow.h>
 #include <qpushbutton.h>
 #include <qscrollbar.h>
+#include <QtWidgets/QGridLayout>
 
 class screenimage : public QMainWindow
 {
     Q_OBJECT
-
 public:
     screenimage(QImage);
     ~screenimage();
+    QGridLayout *gridLayout;
+    QPushButton *about;
 public slots:
     void connectcontrols();
     void saveas();
     void f_1(int);
-
 public:
     QLabel *l;
     QGroupBox *groupBox;
@@ -45,3 +49,5 @@ public:
     QImage buf;
     int image_quality;
 };
+
+#endif // JPAR_H
