@@ -78,6 +78,8 @@ public:
     TreeStruct CurrentTreestruct;
     std::vector<TreeStruct> CurrentParisoTreestruct;
     QString dotsymbol;
+    QJsonArray PreviousJsonObject;
+    int IndexCurrentJsonObject=-1;
 
 public:
     ParisoMathObject();
