@@ -171,13 +171,13 @@ public slots:
                        bool Inspect = true);
     bool VerifiedJsonModel(const QJsonObject &, bool Inspect = true);
     bool VerifiedIsoJsonModel(const QJsonObject &);
-    bool VerifyParEmptySpace(const QJsonObject &);
+    bool VerifyParEmptySpace(const QJsonObject &, bool T4D=false);
     bool VerifyIsoEmptySpace(const QJsonObject &);
     bool VerifyParFieldEmptySpace(const QJsonObject &, const MandatoryParField &);
     QString MandatoryParFieldToQString(const MandatoryParField &);
     bool VerifyIsoFieldEmptySpace(const QJsonObject &, const MandatoryIsoField &);
     QString MandatoryIsoFieldToQString(const MandatoryIsoField &);
-    bool VerifiedParJsonModel(const QJsonObject &);
+    bool VerifiedParJsonModel(const QJsonObject &, bool T4D=false);
     void AddObjectToMySelectionTree();
     void AddIsoObjectToTree(QTreeWidgetItem *, TreeStruct &);
     void AddParObjectToTree(QTreeWidgetItem *, TreeStruct &);
@@ -210,7 +210,9 @@ public slots:
     void on_TNCNDcheckBox_clicked(bool);
     void on_FNCNDcheckBox_clicked(bool);
     void on_actionMesh_triggered();
+    void PreviousJsonObject(const QJsonObject &);
     void on_calculate_clicked();
+    QJsonObject Modeltype(const QJsonObject &);
     void on_actionAbout_2_triggered();
     void LoadNewFileModels(bool upd = false);
     void on_actionLoad_json_script_triggered();
@@ -349,8 +351,18 @@ public slots:
     void on_blue_Diffuse_valueChanged(int);
     void on_transparent_Diffuse_valueChanged(int);
     void on_GLFrontSurfaceSupport_clicked();
+    void on_SaveThButton_2_clicked();
+
 private slots:
     void on_actionbox_triggered();
+    void on_actionUndo_triggered();
+    void on_actionRedo_triggered();
+    void on_actionClear_triggered();
+    void on_SaveThButton_1_clicked();
+    void on_UndoPushButton_clicked();
+    void on_RedoPushButton_clicked();
+    void on_RedoPushButton_0_clicked();
+    void on_UndopushButton_0_clicked();
 };
 
 #endif
