@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2024 by Abderrahman Taha                                *
+ *   Copyright (C) 2025 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -36,7 +36,6 @@ class editor : public QMainWindow
 public:
     explicit editor(QWidget *parent = nullptr);
     ~editor();
-    void about();
     void newFile();
     void openFile(const QString &);
     void setupEditor();
@@ -48,8 +47,6 @@ private slots:
 
     void on_actionNew_triggered();
 
-    void on_actionAbout_triggered();
-
     void on_actionSave_triggered();
 
     void on_actionSave_As_triggered();
