@@ -20,6 +20,44 @@
 #include "mathmod.h"
 
 
+#ifndef GLERROR_H
+#define GLERROR_H
+
+void _check_gl_error(const char *file, int line);
+
+///
+/// Usage
+/// [... some opengl calls]
+/// glCheckError();
+///
+#define check_gl_error() _check_gl_error(__FILE__,__LINE__)
+
+#endif // GLERROR_H
+
+using namespace std;
+
+void _check_gl_error(const char *file, int line) {
+    GLenum err (glGetError());
+
+    while(err!=GL_NO_ERROR) {
+        string error;
+
+        switch(err) {
+        case GL_INVALID_OPERATION:      error="INVALID_OPERATION";      break;
+        case GL_INVALID_ENUM:           error="INVALID_ENUM";           break;
+        case GL_INVALID_VALUE:          error="INVALID_VALUE";          break;
+        case GL_OUT_OF_MEMORY:          error="OUT_OF_MEMORY";          break;
+        case GL_INVALID_FRAMEBUFFER_OPERATION:  error="INVALID_FRAMEBUFFER_OPERATION";  break;
+        default: error="UNKNOWN_ERROR";  break;
+        }
+
+        cerr << "GL_" << error.c_str() <<" - "<<file<<":"<<line<<endl;
+        err=glGetError();
+    }
+}
+
+
+
 void MathMod::CalculateTexturePoints(int type)
 {
     double tmp, val[6]={0,0,0,0,0,0};
@@ -851,12 +889,10 @@ void MathMod::DrawPariso(ObjectProperties *scene, uint ParisoTypeIndex)
                 {
                     glUniform1i(uniformThereisRGBA, 0);
                 }
-                {
-                    size_t Offset = scene->componentsinfos.ParisoTriangle[2*(i+idx)]*sizeof( GL_FLOAT);
-                    glDrawElements(
-                        GL_TRIANGLES,
-                        int(3 * scene->componentsinfos.ParisoTriangle[2 * (i + idx) + 1]),GL_UNSIGNED_INT,(void *)(Offset));
-                }
+                size_t Offset = scene->componentsinfos.ParisoTriangle[2*(i+idx)]*sizeof( GL_FLOAT);
+                glDrawElements(
+                    GL_TRIANGLES,
+                    int(3 * scene->componentsinfos.ParisoTriangle[2 * (i + idx) + 1]),GL_UNSIGNED_INT,(void *)(Offset));
             }
         }
     }
@@ -1241,7 +1277,6 @@ void MathMod::CreateShaderProgram()
        msgBox.adjustSize();
        msgBox.exec();
     }
-
     glAttachShader(shaderprogramId, vertexshader);
     glAttachShader(shaderprogramId, fragmentshader);
     glBindAttribLocation(shaderprogramId, 0, "in_Position");
@@ -1606,11 +1641,11 @@ void MathMod::CopyData(ObjectProperties *scene)
         glGenBuffers(2, vbo);
         /* Bind our first VBO as being the active buffer and storing vertex attributes (coordinates) */
         glBindBuffer(GL_ARRAY_BUFFER, vbo[0]);
-        glBufferData(GL_ARRAY_BUFFER, sizeof(float)*10*(scene->VertxNumber+(12+60+36)),scene->ArrayNorVer_localPt, GL_STATIC_DRAW);
-        glBindBuffer(GL_ARRAY_BUFFER, vbo[0]);
+        glBufferData(GL_ARRAY_BUFFER, sizeof(GL_FLOAT)*10*(scene->VertxNumber+(12+60+36)),scene->ArrayNorVer_localPt, GL_STATIC_DRAW);
+        //glBindBuffer(GL_ARRAY_BUFFER, vbo[0]);
         /* Bind our first VBO as being the active buffer and storing vertex attributes (coordinates) */
         glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, vbo[1]);
-        glBufferData(GL_ELEMENT_ARRAY_BUFFER,sizeof(uint)*(scene->PolyNumber + scene->NbPolygnNbVertexPtMinSize), scene->PolyIndices_localPt, GL_STATIC_DRAW);
+        glBufferData(GL_ELEMENT_ARRAY_BUFFER,sizeof(GLuint)*(scene->PolyNumber + scene->NbPolygnNbVertexPtMinSize), scene->PolyIndices_localPt, GL_STATIC_DRAW);
         size_t cOffset = 0;
         size_t nOffset = cOffset + 4*sizeof( GL_FLOAT);
         size_t vOffset = nOffset + 3*sizeof (GL_FLOAT);
@@ -1620,31 +1655,35 @@ void MathMod::CopyData(ObjectProperties *scene)
         glEnableVertexAttribArray(attribVertexPosition);
         // set attrib arrays using glVertexAttribPointer()
         glVertexAttribPointer(attribVertexPosition, 3, GL_FLOAT, false, 10*sizeof( GL_FLOAT), (void*)vOffset);
-        glVertexAttribPointer(attribVertexNormal, 3, GL_FLOAT, false, 10*sizeof( GL_FLOAT), (void*)nOffset);
         glVertexAttribPointer(attribVertexColor,4, GL_FLOAT, false, 10*sizeof( GL_FLOAT), (void*)cOffset);
+        glVertexAttribPointer(attribVertexNormal, 3, GL_FLOAT, false, 10*sizeof( GL_FLOAT), (void*)nOffset);
         previousVertxNumber = scene->VertxNumber;
         previousPolyNumberNbPolygnNbVertexPtMin = (scene->PolyNumber + scene->NbPolygnNbVertexPtMinSize);
         firstaction++;
     }
-    else{
-        if(scene->VertxNumber>previousVertxNumber)
+    else
+    {
+        glBindBuffer(GL_ARRAY_BUFFER, vbo[0]);
+        glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, vbo[1]);
+        if(scene->VertxNumber>previousVertxNumber>0)
         {
-            glBufferData(GL_ARRAY_BUFFER, sizeof(float)*10*(scene->VertxNumber+(12+60+36)), scene->ArrayNorVer_localPt, GL_STATIC_DRAW);
+            glBufferData(GL_ARRAY_BUFFER, sizeof(GL_FLOAT)*10*(scene->VertxNumber+(12+60+36)), scene->ArrayNorVer_localPt, GL_STATIC_DRAW);
             previousVertxNumber = scene->VertxNumber;
         }
         else
         {
-            glBufferSubData(GL_ARRAY_BUFFER, 0, sizeof(float)*10*(scene->VertxNumber+(12+60+36)), scene->ArrayNorVer_localPt);
+            glBufferSubData(GL_ARRAY_BUFFER, 0, sizeof(GL_FLOAT)*10*(scene->VertxNumber+(12+60+36)), (void *)scene->ArrayNorVer_localPt);
             previousVertxNumber = scene->VertxNumber;
         }
+
         if((scene->PolyNumber + scene->NbPolygnNbVertexPtMinSize)>previousPolyNumberNbPolygnNbVertexPtMin)
         {
-           glBufferData(GL_ELEMENT_ARRAY_BUFFER,sizeof(uint)*(scene->PolyNumber + scene->NbPolygnNbVertexPtMinSize), scene->PolyIndices_localPt, GL_STATIC_DRAW);
-           previousPolyNumberNbPolygnNbVertexPtMin =  (scene->PolyNumber + scene->NbPolygnNbVertexPtMinSize);
+            glBufferData(GL_ELEMENT_ARRAY_BUFFER,sizeof(GLuint)*(scene->PolyNumber + scene->NbPolygnNbVertexPtMinSize), scene->PolyIndices_localPt, GL_STATIC_DRAW);
+            previousPolyNumberNbPolygnNbVertexPtMin =  (scene->PolyNumber + scene->NbPolygnNbVertexPtMinSize);
         }
         else
         {
-            glBufferSubData(GL_ELEMENT_ARRAY_BUFFER,0, sizeof(uint)*(scene->PolyNumber + scene->NbPolygnNbVertexPtMinSize), scene->PolyIndices_localPt);
+            glBufferSubData(GL_ELEMENT_ARRAY_BUFFER,0, sizeof(GLuint)*(scene->PolyNumber + scene->NbPolygnNbVertexPtMinSize), scene->PolyIndices_localPt);
             previousPolyNumberNbPolygnNbVertexPtMin =  (scene->PolyNumber + scene->NbPolygnNbVertexPtMinSize);
         }
     }
@@ -1654,11 +1693,13 @@ void MathMod::draw(ObjectProperties *scene)
 {
     if(!PutObjectInsideCubeOk)
         return;
+
     if (scene->componentsinfos.Interleave)
     {
         CopyData(scene);
         scene->componentsinfos.Interleave = false;
     }
+    glUseProgram(shaderprogramId);
     // clear buffer
     glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
     // set modelview matrix
@@ -1739,7 +1780,6 @@ void MathMod::draw(ObjectProperties *scene)
         for (uint i = 0; i < scene->componentsinfos.NbComponentsType.size(); i++)
             if (scene->componentsinfos.ThereisCND[i])
                 DrawParisoCND(scene, i);
-
     // Draw Normales:
     if (scene->norm == 1 && scene->componentsinfos.updateviewer)
         DrawNormals(scene);
@@ -2348,3 +2388,70 @@ void MathMod::Mesh()
     LocalScene.mesh *= -1;
     update();
 }
+
+int MathMod::TorsionIso()
+{
+    stError = IsoObjet->IsoTorsion();
+    if (stError.iErrorIndex >= 0)
+    {
+        ShowErrormessage();
+        return -1;
+    }
+    return 1;
+}
+
+void MathMod::TorsionIsoSurface()
+{
+    if (!IsoObjet->isRunning())
+    {
+        TorsionIso();
+        LocalScene.typedrawing = 1;
+        IsoObjet->localScene = &(LocalScene);
+        IsoObjet->start(QThread::LowPriority);
+    }
+}
+
+int MathMod::ThickIso()
+{
+    stError = IsoObjet->AddThickness();
+    if (stError.iErrorIndex >= 0)
+    {
+        ShowErrormessage();
+        return -1;
+    }
+    return 1;
+}
+
+void MathMod::AddThicknessToIsoSurface()
+{
+    if (!IsoObjet->isRunning())
+    {
+        ThickIso();
+        LocalScene.typedrawing = 1;
+        IsoObjet->localScene = &(LocalScene);
+        IsoObjet->start(QThread::LowPriority);
+    }
+}
+
+int MathMod::ScaleIso()
+{
+    stError = IsoObjet->ScaleIso();
+    if (stError.iErrorIndex >= 0)
+    {
+        ShowErrormessage();
+        return -1;
+    }
+    return 1;
+}
+
+void MathMod::ScaleIsoSurface()
+{
+    if (!IsoObjet->isRunning())
+    {
+        ScaleIso();
+        LocalScene.typedrawing = 1;
+        IsoObjet->localScene = &(LocalScene);
+        IsoObjet->start(QThread::LowPriority);
+    }
+}
+
