@@ -314,6 +314,12 @@ public slots:
     void CalculatePigmentPoints(int type);
     void LoadShadersFiles();
     void UpdateGL();
+    int  TorsionIso();
+    int  ThickIso();
+    void TorsionIsoSurface();
+    void AddThicknessToIsoSurface();
+    int  ScaleIso();
+    void ScaleIsoSurface();
 };
 
 #endif
